import { createSerialOperation } from '@deep-foundation/deeplinks/imports/gql';
/**
  * Gets serial operations to update {@link LinkName.PushNotification}
  *
  * @example
  * #### Update {@link LinkName.PushNotification}
 ```ts
 const serialOperations = await getPushNotificationValueInsertSerialOperations({
   deep,
   pushNotification: {
     title,
     body,
   }
 });
 await deep.serial({
   operations: serialOperations
 })
 ```
  */
export async function getPushNotificationValueInsertSerialOperations(param) {
    const { deep, pushNotification } = param;
    const pushNotificationLink = await getPushNotificationLink();
    const value = await getValue({
        pushNotificationLink,
        data: pushNotification,
    });
    const serialOperations = await getSerialOperations({
        pushNotificationLink,
        value,
    });
    return serialOperations;
    async function getPushNotificationLink() {
        let pushNotificationLink;
        if ('pushNotificationLinkId' in param) {
            if (!param.pushNotificationLinkId) {
                throw new Error(`pushNotificationLinkId is undefined`);
            }
            const { data } = await deep.select({
                id: param.pushNotificationLinkId,
            });
            pushNotificationLink = data[0];
        }
        else if ('pushNotificationLink' in param) {
            if (!param.pushNotificationLink) {
                throw new Error(`pushNotificationLink is undefined`);
            }
            pushNotificationLink = param.pushNotificationLink;
        }
        else {
            throw new Error(`Either pushNotificationLink or pushNotificationLinkId must be passed`);
        }
        return pushNotificationLink;
    }
    async function getValueInsertSerialOperation({ pushNotificationLink, value, }) {
        return createSerialOperation({
            table: 'objects',
            type: 'insert',
            objects: {
                link_id: pushNotificationLink.id,
                value: value,
            },
        });
    }
    async function getValueUpdateSerialOperation({ pushNotificationLink, value, }) {
        return createSerialOperation({
            table: 'objects',
            type: 'update',
            exp: {
                link_id: pushNotificationLink.id,
            },
            value: {
                value: value,
            },
        });
    }
    async function getValue({ pushNotificationLink, data, }) {
        return {
            ...(pushNotificationLink.value?.value ?? {}),
            ...(data),
        };
    }
    async function getSerialOperations({ pushNotificationLink, value, }) {
        let serialOperations = [];
        if (!pushNotificationLink.value) {
            serialOperations.push(await getValueUpdateSerialOperation({
                pushNotificationLink,
                value,
            }));
        }
        else {
            serialOperations.push(await getValueInsertSerialOperation({
                pushNotificationLink,
                value,
            }));
        }
        return serialOperations;
    }
}
