import { DeepClient, SerialOperation } from '@deep-foundation/deeplinks/imports/client';
import { Link } from '@deep-foundation/deeplinks/imports/minilinks';
/**
  * Gets serial operations to update {@link LinkName.WebPushCertificate}
  *
  * @example
  * #### Update {@link LinkName.WebPushCertificate}
 ```ts
 const serialOperations = await getWebPushCertificateValueInsertSerialOperations({
   deep,
   webPushCertificate: {
     title,
     body,
   }
 });
 await deep.serial({
   operations: serialOperations
 })
 ```
  */
export declare function getWebPushCertificateValueInsertSerialOperations(param: GetWebPushCertificateValueUpdateSerialOperationsParam): Promise<Array<SerialOperation>>;
export type GetWebPushCertificateValueUpdateSerialOperationsParam = {
    /**
     * DeepClient
     */
    deep: DeepClient;
    /**
     * WebPushCertificate
     */
    webPushCertificate: string;
} & ({
    /**
     * WebPushCertificate Link Id
     */
    webPushCertificateLinkId: number;
} | {
    /**
     * WebPushCertificate Link
     */
    webPushCertificateLink: Link<number>;
});
